@@ -2,12 +2,15 @@
 from __future__ import annotations
 
 import asyncio
-from typing import TYPE_CHECKING, Any, Callable, Coroutine
+import traceback
+from typing import TYPE_CHECKING
 
 from fastapi import FastAPI, Request, Response, status
 import uvicorn
 
 from ecowitt2mqtt.const import LOGGER
+from ecowitt2mqtt.helpers.publisher import PublishError
+from ecowitt2mqtt.helpers.publisher.factory import get_publisher
 
 if TYPE_CHECKING:
     from ecowitt2mqtt.core import Ecowitt
@@ -23,20 +26,13 @@ class Server:
 
     def __init__(self, ecowitt: Ecowitt) -> None:
         """Initialize."""
-        self._device_payload_callbacks: list[
-            Callable[[dict[str, Any]], Coroutine | None]
-        ] = []
         self._loop = asyncio.get_event_loop()
         self._startup_task: asyncio.Task | None = None
 
         self.app = FastAPI()
-        self.app.post(
-            ecowitt.config.endpoint,
-            status_code=status.HTTP_204_NO_CONTENT,
-            response_class=Response,
-        )(self._async_post_data)
-
-        self._server = uvicorn.Server(
+        self.ecowitt = ecowitt
+        self.publisher = get_publisher(ecowitt)
+        self.server = uvicorn.Server(
             config=uvicorn.Config(
                 self.app,
                 host=DEFAULT_HOST,
@@ -46,29 +42,20 @@ class Server:
             )
         )
 
-        self.ecowitt = ecowitt
-
     async def _async_post_data(self, request: Request) -> Response:
         """Define an endpoint for the Ecowitt device to post data to."""
         payload = await request.form()
         LOGGER.debug("Received data from the Ecowitt device: %s", dict(payload))
-        for callback in self._device_payload_callbacks:
-            if asyncio.iscoroutinefunction(callback):
-                self._loop.create_task(callback(payload))  # type: ignore
-            else:
-                callback(payload)
 
-    def add_device_payload_callback(
-        self, callback: Callable[[dict[str, Any]], Coroutine | None]
-    ) -> Callable[..., None]:
-        """Add a callback to be executed when a new device payload is received."""
-        self._device_payload_callbacks.append(callback)
+        try:
+            await self.publisher.async_publish(payload)
+        except PublishError as err:
+            LOGGER.error("Unable to publish payload: %s", err)
+            LOGGER.debug("".join(traceback.format_tb(err.__traceback__)))
 
-        def remove() -> None:
-            """Remove the callback."""
-            self._device_payload_callbacks.remove(callback)
-
-        return remove
+        if self.ecowitt.config.diagnostics:
+            LOGGER.debug("*** DIAGNOSTICS COLLECTED")
+            self.stop()
 
     async def async_start(self) -> None:
         """Start the REST API server."""
@@ -79,7 +66,13 @@ class Server:
             self.ecowitt.config.endpoint,
         )
 
-        self._startup_task = self._loop.create_task(self._server.serve())
+        self.app.post(
+            self.ecowitt.config.endpoint,
+            status_code=status.HTTP_204_NO_CONTENT,
+            response_class=Response,
+        )(self._async_post_data)
+
+        self._startup_task = self._loop.create_task(self.server.serve())
         try:
             await self._startup_task
         except asyncio.CancelledError:
